package com.srs.staff.mapper;

import java.util.List;
import java.util.Map;

import com.srs.staff.domain.SrsStaffOneStopRegistrationRecord;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.staff.domain.vo.SrsStaffOneStopRegistrationRecordExportVo;
import org.apache.ibatis.annotations.Param;

/**
 * 一站式社区模块-社区活动-报名记录Mapper接口
 *
 * @author chc
 * @date 2024-07-16
 */
public interface SrsStaffOneStopRegistrationRecordMapper extends BaseMapper<SrsStaffOneStopRegistrationRecord> {
    /**
     * 查询一站式社区模块-社区活动-报名记录
     *
     * @param recordId 一站式社区模块-社区活动-报名记录主键
     * @return 一站式社区模块-社区活动-报名记录
     */
    public SrsStaffOneStopRegistrationRecord selectSrsStaffOneStopRegistrationRecordByRecordId(Long recordId);

    /**
     * 查询一站式社区模块-社区活动-报名记录
     *
     * @param activityId 一站式社区模块-社区活动-报名记录主键
     * @return 一站式社区模块-社区活动-报名记录
     */
    public List<SrsStaffOneStopRegistrationRecord> selectSrsStaffOneStopRegistrationRecordByActivityId(Long activityId);


    /**
     * 查询一站式社区模块-社区活动-报名记录
     *
     * @param activityId 一站式社区模块-社区活动主键
     * @return 一站式社区模块-社区活动-报名记录
     */
    public SrsStaffOneStopRegistrationRecord selectRecordByActivityIdAndApplicant(@Param("activityId") Long activityId, @Param("jobNumber") String jobNumber);

    /**
     * 查询一站式社区模块-社区活动-报名记录列表
     *
     * @param srsStaffOneStopRegistrationRecord 一站式社区模块-社区活动-报名记录
     * @return 一站式社区模块-社区活动-报名记录集合
     */
    List<SrsStaffOneStopRegistrationRecord> selectSrsStaffOneStopRegistrationRecordList(SrsStaffOneStopRegistrationRecord srsStaffOneStopRegistrationRecord);

    /**
     * 新增一站式社区模块-社区活动-报名记录
     *
     * @param srsStaffOneStopRegistrationRecord 一站式社区模块-社区活动-报名记录
     * @return 结果
     */
    int insertSrsStaffOneStopRegistrationRecord(SrsStaffOneStopRegistrationRecord srsStaffOneStopRegistrationRecord);

    /**
     * 修改一站式社区模块-社区活动-报名记录
     *
     * @param srsStaffOneStopRegistrationRecord 一站式社区模块-社区活动-报名记录
     * @return 结果
     */
    int updateSrsStaffOneStopRegistrationRecord(SrsStaffOneStopRegistrationRecord srsStaffOneStopRegistrationRecord);

    /**
     * 批量修改一站式社区模块-社区活动-报名记录
     *
     * @param registrationRecordList 一站式社区模块-社区活动-报名记录
     * @return 结果
     */
    int batchUpdateSysRegistrationRecord(List<SrsStaffOneStopRegistrationRecord> registrationRecordList);

    /**
     * 删除一站式社区模块-社区活动-报名记录
     *
     * @param recordId 一站式社区模块-社区活动-报名记录主键
     * @return 结果
     */
    int deleteSrsStaffOneStopRegistrationRecordByRecordId(Long recordId);

    /**
     * 批量删除一站式社区模块-社区活动-报名记录
     *
     * @param recordIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSrsStaffOneStopRegistrationRecordByRecordIds(Long[] recordIds);

    /**
     * 导出
     * @param srsStaffOneStopRegistrationRecord
     * @return
     */
    List<SrsStaffOneStopRegistrationRecordExportVo> selectSrsStaffOneStopRegistrationRecordListexport(SrsStaffOneStopRegistrationRecord srsStaffOneStopRegistrationRecord);

    List<Map<String, Object>> getDepartmentUsage(
            @Param("startTime") String startTime,
            @Param("endTime") String endTime,
            @Param("role") String role,
            @Param("borrower") String borrower,
            @Param("auditStatus") Integer auditStatus,
            @Param("rtDepar") List<String> rtDepar
    );

    List<Map<String, Object>> getRoomReservationCount(
            @Param("startTime") String startTime,
            @Param("endTime") String endTime,
            @Param("role") String role,
            @Param("borrower") String borrower,
            @Param("auditStatus") Integer auditStatus,
            @Param("rtDepar") List<String> rtDepar
    );

    List<Map<String, Object>> getDepartmentUsageStatistics(
            @Param("startTime") String startTime,
            @Param("endTime") String endTime,
            @Param("role") String role,
            @Param("borrower") String borrower,
            @Param("auditStatus") Integer auditStatus,
            @Param("rtDepar") List<String> rtDepar
    );

    List<Map<String, Object>> getRoomUsageStatistics(
            @Param("startTime") String startTime,
            @Param("endTime") String endTime,
            @Param("role") String role,
            @Param("borrower") String borrower,
            @Param("auditStatus") Integer auditStatus,
            @Param("rtDepar") List<String> rtDepar
    );

    int updateAuditStatusToPending(@Param("id") Integer id);
}
